@@ -1,7 +1,7 @@
 #
 # -*- Mode: Python; python-indent-offset: 4 -*-
 #
-# Time-stamp: <2020-04-13 16:07:53 alex>
+# Time-stamp: <2021-03-04 18:26:15 alex>
 #
 
 """
@@ -68,12 +68,19 @@ class Space(ClassParams):
         if self.sds is None:
             raise SDSSpaceError(message="not connected")
 
-        space_id = self._get_siteid_by_name(self.name)
+        space_id = None
+        try:
+            space_id = self._get_id_by_name('ip_site_list', 'site', self.name)
+        except SDSError:
+            None  # pylint: disable=W0104
+
+        # space_id = self._get_siteid_by_name(self.name)
         if space_id is not None:
             raise SDSSpaceError(message="already existant space")
 
         params = {
-            'site_name': self.name
+            'site_name': self.name,
+            **self.additional_params
         }
 
         self.prepare_class_params('site', params)
@@ -99,12 +106,14 @@ class Space(ClassParams):
         if self.sds is None:
             raise SDSSpaceError(message="not connected")
 
-        space_id = self._get_siteid_by_name(self.name)
+        # space_id = self._get_siteid_by_name(self.name)
+        space_id = self._get_id_by_name('ip_site_list', 'site', self.name)
 
         try:
             rjson = self.sds.query("ip_site_delete",
                                    params={
                                        'site_id': space_id,
+                                       **self.additional_params
                                    })
             if 'errmsg' in rjson:  # pragma: no cover
                 raise SDSSpaceError(message="space delete error, "
@@ -112,24 +121,6 @@ class Space(ClassParams):
         except SDSError:   # pragma: no cover
             raise SDSSpaceError(message="space delete error")
 
-    # -------------------------------------
-    def _get_siteid_by_name(self, name):
-        """get the space ID from its name, return None if non existant"""
-
-        try:
-            rjson = self.sds.query("ip_site_list",
-                                   params={
-                                       "WHERE": "site_name='{}'".
-                                                format(name),
-                                   })
-        except SDSEmptyError:
-            return None
-
-        if rjson[0]['errno'] != '0':   # pragma: no cover
-            raise SDSError("errno raised")
-
-        return rjson[0]['site_id']
-
     # -------------------------------------
     def refresh(self):
         """refresh content of the object from the SDS"""
@@ -137,7 +128,7 @@ class Space(ClassParams):
             raise SDSInitError(message="not connected")
 
         if self.params['site_id'] is None:
-            space_id = self._get_siteid_by_name(self.name)
+            space_id = self._get_id_by_name('ip_site_list', 'site', self.name)
         else:
             space_id = self.params['site_id']
 
@@ -147,6 +138,7 @@ class Space(ClassParams):
         rjson = self.sds.query("ip_site_info",
                                params={
                                    "site_id": space_id,
+                                   **self.additional_params
                                })
 
         if not rjson:   # pragma: no cover
